﻿// Copyright (C) 2009 Choonghwan Lee (linjus.lee@gmail.com)
//
// This file is part of amanda.
//
// amanda is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// amanda is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with amanda. If not, see <http://www.gnu.org/licenses/>.

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace manager
{
	/// <summary>
	/// Interaction logic for Wizard2Device.xaml
	/// </summary>
	public partial class Wizard2Device : PageFunction<WizardResult>
	{
		private WizardData data;

		public Wizard2Device(WizardData data)
		{
			InitializeComponent();

			this.data = data;

			this.Loaded += new RoutedEventHandler(Wizard2Device_Loaded);
		}

		private void FillDescription(int validitems)
		{
			if (this.data.LibraryInfo == null) return;

			string msg =
				"In the previous step, you chose '" + this.data.LibraryInfo.Name + "'. " +
				"The device that corresponds to this library is '" + this.data.LibraryInfo.DeviceName + "'.\r\n\r\n";
			if (validitems != -1)
				msg += validitems + " files were detected. You may want to check files from the main window.";
			else
				msg += "Connect '" + this.data.LibraryInfo.DeviceName + "' and make sure that that device is mounted as '" + this.data.LibraryInfo.DeviceRootPath + "'.";

			this.textDescription.Text = msg;
		}

		private void ReadRootPath()
		{
			Global.MainWindow.ResetLibrary();

			int validitems = -1;
			try {
				if (this.data.LibraryInfo != null) {
					validitems = Global.MainWindow.ReadDevice(this.data.LibraryInfo);
				}
			}
			catch (Exception e) {
			}
			finally {
				this.FillDescription(validitems);
				this.buttonNext.IsEnabled = validitems != -1;
			}
		}

		private void buttonCheck_Click(object sender, RoutedEventArgs e)
		{
			this.ReadRootPath();
		}

		void Wizard2Device_Loaded(object sender, RoutedEventArgs e)
		{
			this.ReadRootPath();
		}

		private void buttonNext_Click(object sender, RoutedEventArgs e)
		{
			PageFunction<WizardResult> page = new Wizard3Foobar2000(this.data);
			page.Return += (object s, ReturnEventArgs<WizardResult> ev) => this.OnReturn(ev);
			this.NavigationService.Navigate(page);
		}
	}
}
